@@ -68,7 +68,6 @@ GtkWidget *totem_pp_create (void);
 #endif
 
 typedef enum {
-	TOTEM_PLUGIN_TYPE_BASIC,
 	TOTEM_PLUGIN_TYPE_GMP,
 	TOTEM_PLUGIN_TYPE_COMPLEX,
 	TOTEM_PLUGIN_TYPE_NARROWSPACE,
@@ -304,9 +303,9 @@ totem_embedded_set_error (TotemEmbedded *emb,
 			  int code,
 			  char *secondary)
 {
-	emb->error = g_error_new (TOTEM_EMBEDDED_ERROR_QUARK,
-				  code,
-				  secondary);
+	emb->error = g_error_new_literal (TOTEM_EMBEDDED_ERROR_QUARK,
+	                                  code,
+	                                  secondary);
 	g_message ("totem_embedded_set_error: '%s'", secondary);
 }
 
@@ -761,7 +760,10 @@ totem_embedded_set_uri (TotemEmbedded *emb,
 	emb->is_browser_stream = (is_browser_stream != FALSE);
 	emb->href_uri = NULL;
 
-        g_print ("totem_embedded_set_uri uri %s base %s => resolved %s\n", uri, base_uri, emb->current_uri);
+	if (uri != NULL)
+		g_print ("totem_embedded_set_uri uri %s base %s => resolved %s\n", uri, base_uri, emb->current_uri);
+	else
+		g_print ("Emptying current_uri\n");
 
 	g_free (old_uri);
 	g_free (old_base);
@@ -1530,6 +1532,8 @@ on_eos_event (BaconVideoWidget *bvw, TotemEmbedded *emb)
 			if (bacon_video_widget_is_seekable (emb->bvw) != FALSE) {
 				bacon_video_widget_pause (emb->bvw);
 				bacon_video_widget_seek (emb->bvw, 0.0, NULL);
+				if (start_play != FALSE)
+					totem_embedded_play (emb, NULL);
 			} else {
 				bacon_video_widget_close (emb->bvw);
 				totem_embedded_open_internal (emb, start_play, NULL /* FIXME? */);
@@ -2203,7 +2207,6 @@ parse_plugin_type (const gchar *option_name,
 	           GError **error)
 {
 	const char types[TOTEM_PLUGIN_TYPE_LAST][12] = {
-		"basic",
 		"gmp",
 		"complex",
 		"narrowspace",
