@@ -29,9 +29,7 @@
 
 #include <glib/gi18n.h>
 
-#include <gtk/gtklabel.h>
-#include <gtk/gtkvseparator.h>
-#include <gtk/gtkversion.h>
+#include <gtk/gtk.h>
 
 #include "totem-statusbar.h"
 #include "video-utils.h"
@@ -40,14 +38,8 @@
 #define NORMAL_CONTEXT "text"
 #define BUFFERING_CONTEXT "buffering"
 
-static void totem_statusbar_class_init       (TotemStatusbarClass *class);
-static void totem_statusbar_init             (TotemStatusbar      *statusbar);
 static void totem_statusbar_dispose          (GObject             *object);
 static void totem_statusbar_sync_description (TotemStatusbar      *statusbar);
-#if !GTK_CHECK_VERSION (2, 11, 0)
-static void totem_statusbar_size_allocate    (GtkWidget           *widget,
-                                              GtkAllocation       *allocation);
-#endif
 
 G_DEFINE_TYPE(TotemStatusbar, totem_statusbar, GTK_TYPE_STATUSBAR)
 
@@ -55,11 +47,6 @@ static void
 totem_statusbar_class_init (TotemStatusbarClass *klass)
 {
   GObjectClass *gobject_class = G_OBJECT_CLASS (klass);
-#if !GTK_CHECK_VERSION (2, 11, 0)
-  GtkWidgetClass *widget_class = GTK_WIDGET_CLASS (klass);
-
-  widget_class->size_allocate = totem_statusbar_size_allocate;
-#endif
 
   gobject_class->dispose = totem_statusbar_dispose;
 }
@@ -232,10 +219,9 @@ totem_statusbar_push (TotemStatusbar *statusbar, guint percentage)
 
   if (statusbar->timeout == 0)
   {
-    statusbar->timeout = g_timeout_add (1000,
-                    (GSourceFunc) totem_statusbar_timeout_pop, statusbar);
+    statusbar->timeout = g_timeout_add_seconds (1, (GSourceFunc) totem_statusbar_timeout_pop, statusbar);
   }
-  
+
   if (need_update)
     totem_statusbar_sync_description (statusbar);
 }
@@ -315,25 +301,6 @@ totem_statusbar_dispose (GObject *object)
   G_OBJECT_CLASS (totem_statusbar_parent_class)->dispose (object);
 }
 
-#if !GTK_CHECK_VERSION (2, 11, 0)
-static void
-totem_statusbar_size_allocate (GtkWidget *widget,
-                               GtkAllocation *allocation)
-{
-  GtkStatusbar *gstatusbar = GTK_STATUSBAR (widget);
-  GtkWidget *label, *box;
-
-  /* HACK HACK HACK ! */
-  label = gstatusbar->label;
-  box = gtk_bin_get_child (GTK_BIN (gstatusbar->frame));
-  gstatusbar->label = box;
-
-  GTK_WIDGET_CLASS (totem_statusbar_parent_class)->size_allocate (widget, allocation);
-
-  gstatusbar->label = label;
-}
-#endif /* !GTK 2.11.0 */
-
 /*
  * vim: sw=2 ts=8 cindent noai bs=2
  */
