@@ -36,10 +36,6 @@
 #include <math.h>
 #include <gio/gio.h>
 
-#ifndef HAVE_GTK_ONLY
-#include <gnome.h>
-#endif /* !HAVE_GTK_ONLY */
-
 #include <string.h>
 
 #ifdef GDK_WINDOWING_X11
@@ -56,13 +52,13 @@
 #include "totem-statusbar.h"
 #include "totem-time-label.h"
 #include "totem-session.h"
-#include "totem-screenshot.h"
 #include "totem-sidebar.h"
 #include "totem-menu.h"
 #include "totem-options.h"
 #include "totem-uri.h"
 #include "totem-interface.h"
 #include "video-utils.h"
+#include "totem-dnd-menu.h"
 
 #include "totem.h"
 #include "totem-private.h"
@@ -155,7 +151,7 @@ totem_action_error (const char *title, const char *reason, Totem *totem)
 			GTK_WINDOW (totem->win));
 }
 
-static void
+G_GNUC_NORETURN static void
 totem_action_error_and_exit (const char *title,
 		const char *reason, Totem *totem)
 {
@@ -220,7 +216,7 @@ totem_action_save_state (Totem *totem, const char *page_id)
 	g_free (contents);
 }
 
-static void
+G_GNUC_NORETURN static void
 totem_action_wait_force_exit (gpointer user_data)
 {
 	g_usleep (10 * G_USEC_PER_SEC);
@@ -268,7 +264,10 @@ totem_action_exit (Totem *totem)
 	if (totem->bvw) {
 		int vol;
 
-		vol = bacon_video_widget_get_volume (totem->bvw) * 100.0 + 0.5;
+		if (totem->muted != FALSE)
+			vol = totem->prev_volume * 100.0 + 0.5;
+		else
+			vol = bacon_video_widget_get_volume (totem->bvw) * 100.0 + 0.5;
 		/* FIXME move the volume to the static file? */
 		gconf_client_set_int (totem->gc,
 				GCONF_PREFIX"/volume",
@@ -311,12 +310,10 @@ totem_action_menu_popup (Totem *totem, guint button)
 	gtk_menu_shell_select_first (GTK_MENU_SHELL (menu), FALSE);
 }
 
-gboolean
+G_GNUC_NORETURN gboolean
 main_window_destroy_cb (GtkWidget *widget, GdkEvent *event, Totem *totem)
 {
 	totem_action_exit (totem);
-
-	return FALSE;
 }
 
 static void
@@ -913,79 +910,56 @@ totem_action_open_location (Totem *totem)
 	gtk_widget_show (GTK_WIDGET (totem->open_location));
 }
 
-void
-totem_action_take_screenshot (Totem *totem)
-{
-	GdkPixbuf *pixbuf;
-	GtkWidget *dialog;
-	char *filename;
-	GError *err = NULL;
-
-	if (bacon_video_widget_get_logo_mode (totem->bvw) != FALSE)
-		return;
-
-	if (bacon_video_widget_can_get_frames (totem->bvw, &err) == FALSE)
-	{
-		if (err == NULL)
-			return;
-
-		totem_action_error (_("Totem could not get a screenshot of that film."), err->message, totem);
-		g_error_free (err);
-		return;
-	}
-
-	pixbuf = bacon_video_widget_get_current_frame (totem->bvw);
-	if (pixbuf == NULL)
-	{
-		totem_action_error (_("Totem could not get a screenshot of that film."), _("This is not supposed to happen; please file a bug report."), totem);
-		return;
-	}
-
-	filename = g_build_filename (DATADIR,
-			"totem", "screenshot.ui", NULL);
-	dialog = totem_screenshot_new (pixbuf);
-	g_free (filename);
-
-	gtk_dialog_run (GTK_DIALOG (dialog));
-	gtk_widget_destroy (dialog);
-	g_object_unref (pixbuf);
-}
-
 static char *
 totem_get_nice_name_for_stream (Totem *totem)
 {
-	char *title, *artist, *retval;
-	int tracknum;
+	GValue title_value = { 0, };
+	GValue album_value = { 0, };
+	GValue artist_value = { 0, };
 	GValue value = { 0, };
+	char *retval;
+	int tracknum;
 
-	bacon_video_widget_get_metadata (totem->bvw, BVW_INFO_TITLE, &value);
-	title = g_value_dup_string (&value);
-	g_value_unset (&value);
-
-	if (title == NULL)
-		return NULL;
-
-	bacon_video_widget_get_metadata (totem->bvw, BVW_INFO_ARTIST, &value);
-	artist = g_value_dup_string (&value);
-	g_value_unset (&value);
-
-	if (artist == NULL)
-		return title;
-
+	bacon_video_widget_get_metadata (totem->bvw, BVW_INFO_TITLE, &title_value);
+	bacon_video_widget_get_metadata (totem->bvw, BVW_INFO_ARTIST, &artist_value);
+	bacon_video_widget_get_metadata (totem->bvw, BVW_INFO_ALBUM, &album_value);
 	bacon_video_widget_get_metadata (totem->bvw,
 					 BVW_INFO_TRACK_NUMBER,
 					 &value);
+
 	tracknum = g_value_get_int (&value);
 	g_value_unset (&value);
 
+	totem_metadata_updated (totem,
+				g_value_get_string (&artist_value),
+				g_value_get_string (&title_value),
+				g_value_get_string (&album_value),
+				tracknum);
+
+	if (g_value_get_string (&title_value) == NULL) {
+		retval = NULL;
+		goto bail;
+	}
+	if (g_value_get_string (&artist_value) == NULL) {
+		retval = g_value_dup_string (&title_value);
+		goto bail;
+	}
+
 	if (tracknum != 0) {
 		retval = g_strdup_printf ("%02d. %s - %s",
-				tracknum, artist, title);
+					  tracknum,
+					  g_value_get_string (&artist_value),
+					  g_value_get_string (&title_value));
 	} else {
-		retval = g_strdup_printf ("%s - %s", artist, title);
+		retval = g_strdup_printf ("%s - %s",
+					  g_value_get_string (&artist_value),
+					  g_value_get_string (&title_value));
 	}
-	g_free (artist);
-	g_free (title);
+
+bail:
+	g_value_unset (&album_value);
+	g_value_unset (&artist_value);
+	g_value_unset (&title_value);
 
 	return retval;
 }
@@ -1012,7 +986,7 @@ update_mrl_label (Totem *totem, const char *name)
 		totem_fullscreen_set_title (totem->fs, NULL);
 
 		/* Title */
-		gtk_window_set_title (GTK_WINDOW (totem->win), _("Totem Movie Player"));
+		gtk_window_set_title (GTK_WINDOW (totem->win), _("Movie Player"));
 	}
 }
 
@@ -1072,12 +1046,12 @@ totem_action_set_mrl_with_warning (Totem *totem,
 		totem_action_set_sensitivity ("next-chapter", FALSE);
 		totem_action_set_sensitivity ("previous-chapter", FALSE);
 
-		/* Take a screenshot */
-		totem_action_set_sensitivity ("take-screenshot", FALSE);
-
 		/* Clear the playlist */
 		totem_action_set_sensitivity ("clear-playlist", FALSE);
 
+		/* Subtitle selection */
+		totem_action_set_sensitivity ("select-subtitle", FALSE);
+
 		/* Set the logo */
 		bacon_video_widget_set_logo_mode (totem->bvw, TRUE);
 		update_mrl_label (totem, NULL);
@@ -1111,12 +1085,12 @@ totem_action_set_mrl_with_warning (Totem *totem,
 		totem_action_set_sensitivity ("volume-down", caps && volume > VOLUME_EPSILON);
 		totem->volume_sensitive = caps;
 
-		/* Take a screenshot */
-		totem_action_set_sensitivity ("take-screenshot", retval);
-
 		/* Clear the playlist */
 		totem_action_set_sensitivity ("clear-playlist", retval);
 
+		/* Subtitle selection */
+		totem_action_set_sensitivity ("select-subtitle", !totem_is_special_mrl (mrl) && retval);
+	
 		/* Set the playlist */
 		play_pause_set_label (totem, retval ? STATE_PAUSED : STATE_STOPPED);
 
@@ -1362,9 +1336,10 @@ totem_action_zoom_reset (Totem *totem)
 /**
  * totem_action_volume_relative:
  * @totem: a #TotemObject
- * @off_pct: the percentage by which to increase or decrease the volume
+ * @off_pct: the value by which to increase or decrease the volume
  *
- * Sets the volume relative to its current level.
+ * Sets the volume relative to its current level, with 1.0 being the
+ * maximum, and 0.0 being the minimum level.
  **/
 void
 totem_action_volume_relative (Totem *totem, double off_pct)
@@ -1373,11 +1348,32 @@ totem_action_volume_relative (Totem *totem, double off_pct)
 
 	if (bacon_video_widget_can_set_volume (totem->bvw) == FALSE)
 		return;
+	if (totem->muted != FALSE)
+		totem_action_volume_toggle_mute (totem);
 
 	vol = bacon_video_widget_get_volume (totem->bvw);
 	bacon_video_widget_set_volume (totem->bvw, vol + off_pct);
 }
 
+/**
+ * totem_action_volume_toggle_mute:
+ * @totem: a #TotemObject
+ *
+ * Toggles the mute status.
+ **/
+void
+totem_action_volume_toggle_mute (Totem *totem)
+{
+	if (totem->muted == FALSE) {
+		totem->muted = TRUE;
+		totem->prev_volume = bacon_video_widget_get_volume (totem->bvw);
+		bacon_video_widget_set_volume (totem->bvw, 0.0);
+	} else {
+		totem->muted = FALSE;
+		bacon_video_widget_set_volume (totem->bvw, totem->prev_volume);
+	}
+}
+
 /**
  * totem_action_toggle_aspect_ratio:
  * @totem: a #TotemObject
@@ -1458,15 +1454,24 @@ totem_action_drop_files (Totem *totem, GtkSelectionData *data,
 		int drop_type, gboolean empty_pl)
 {
 	char **list;
-	guint i;
+	guint i, len;
 	GList *p, *file_list;
 	gboolean cleared = FALSE;
 
 	list = g_uri_list_extract_uris ((const char *)data->data);
 	file_list = NULL;
 
-	for (i = 0; list[i] != NULL; ++i)
-		file_list = g_list_prepend (file_list, list[i]);
+	for (i = 0; list[i] != NULL; i++) {
+		char *filename;
+
+		if (list[i] == NULL)
+			continue;
+
+		filename = totem_create_full_path (list[i]);
+		file_list = g_list_prepend (file_list,
+					    filename ? filename : g_strdup (list[i]));
+	}
+	g_strfreev (list);
 
 	if (file_list == NULL)
 		return FALSE;
@@ -1478,20 +1483,23 @@ totem_action_drop_files (Totem *totem, GtkSelectionData *data,
 	else
 		file_list = g_list_reverse (file_list);
 
-	for (p = file_list; p != NULL; p = p->next)
-	{
-		char *filename, *title;
+	/* How many files? Check whether those could be subtitles */
+	len = g_list_length (file_list);
+	if (len == 1 || (len == 2 && drop_type == 1)) {
+		if (totem_uri_is_subtitle (file_list->data) != FALSE) {
+			totem_playlist_set_current_subtitle (totem->playlist, file_list->data);
+			goto bail;
+		}
+	}
 
-		if (p->data == NULL)
-			continue;
+	for (p = file_list; p != NULL; p = p->next) {
+		const char *filename;
+		char *title;
 
-		filename = totem_create_full_path (p->data);
-		if (filename == NULL)
-			filename = g_strdup (p->data);
+		filename = p->data;
 		title = NULL;
 
-		if (empty_pl != FALSE && cleared == FALSE)
-		{
+		if (empty_pl != FALSE && cleared == FALSE) {
 			/* The function that calls us knows better
 			 * if we should be doing something with the 
 			 * changed playlist ... */
@@ -1503,11 +1511,10 @@ totem_action_drop_files (Totem *totem, GtkSelectionData *data,
 		}
 
 		/* Super _NETSCAPE_URL trick */
-		if (drop_type == 1)
-		{
+		if (drop_type == 1) {
 			p = p->next;
 			if (p != NULL) {
-				if (g_str_has_prefix (p->data, "file:") != FALSE)
+				if (g_str_has_prefix (p->data, "File:") != FALSE)
 					title = (char *)p->data + 5;
 				else
 					title = p->data;
@@ -1515,11 +1522,10 @@ totem_action_drop_files (Totem *totem, GtkSelectionData *data,
 		}
 
 		totem_playlist_add_mrl (totem->playlist, filename, title);
-
-		g_free (filename);
 	}
 
-	g_strfreev (list);
+bail:
+	g_list_foreach (file_list, (GFunc) g_free, NULL);
 	g_list_free (file_list);
 	gdk_window_set_cursor (totem->win->window, NULL);
 
@@ -1550,10 +1556,38 @@ drop_video_cb (GtkWidget     *widget,
 	 guint               time,
 	 Totem              *totem)
 {
-	gboolean retval;
+	gboolean empty_pl;
 
-	retval = totem_action_drop_files (totem, data, info, TRUE);
-	gtk_drag_finish (context, retval, FALSE, time);
+	if (context->suggested_action == GDK_ACTION_ASK)
+		context->action = totem_drag_ask (totem_get_playlist_length (totem) > 0);
+
+	if (context->action != GDK_ACTION_DEFAULT) {
+		empty_pl = (context->action == GDK_ACTION_MOVE);
+		totem_action_drop_files (totem, data, info, empty_pl);
+		gtk_drag_finish (context, TRUE, FALSE, time);
+		return;
+	}
+	gtk_drag_finish (context, FALSE, FALSE, time);
+}
+
+static void
+drag_motion_video_cb (GtkWidget      *widget,
+                      GdkDragContext *context,
+                      gint            x,
+                      gint            y,
+                      guint           time,
+                      Totem          *totem)
+{
+	GdkModifierType mask;
+
+	gdk_window_get_pointer (widget->window, NULL, NULL, &mask);
+	if (mask & GDK_CONTROL_MASK) {
+		gdk_drag_status (context, GDK_ACTION_COPY, time);
+	} else if (mask & GDK_MOD1_MASK || context->suggested_action == GDK_ACTION_ASK) {
+		gdk_drag_status (context, GDK_ACTION_ASK, time);
+	} else {
+		gdk_drag_status (context, GDK_ACTION_MOVE, time);
+	}
 }
 
 static void
@@ -1566,12 +1600,38 @@ drop_playlist_cb (GtkWidget     *widget,
 	       guint               time,
 	       Totem              *totem)
 {
-	gboolean retval;
+	gboolean empty_pl;
 
-	retval = totem_action_drop_files (totem, data, info, FALSE);
-	gtk_drag_finish (context, retval, FALSE, time);
+	if (context->suggested_action == GDK_ACTION_ASK)
+		context->action = totem_drag_ask (totem_get_playlist_length (totem) > 0);
+
+	if (context->action == GDK_ACTION_DEFAULT) {
+		gtk_drag_finish (context, FALSE, FALSE, time);
+		return;
+	}
+
+	empty_pl = (context->action == GDK_ACTION_MOVE);
+
+	totem_action_drop_files (totem, data, info, empty_pl);
+	gtk_drag_finish (context, TRUE, FALSE, time);
 }
 
+static void
+drag_motion_playlist_cb (GtkWidget      *widget,
+			 GdkDragContext *context,
+			 gint            x,
+			 gint            y,
+			 guint           time,
+			 Totem          *totem)
+{
+	GdkModifierType mask;
+
+	gdk_window_get_pointer (widget->window, NULL, NULL, &mask);
+
+	if (mask & GDK_MOD1_MASK || context->suggested_action == GDK_ACTION_ASK) {
+		gdk_drag_status (context, GDK_ACTION_ASK, time);
+	}
+}
 static void
 drag_video_cb (GtkWidget *widget,
 	       GdkDragContext *context,
@@ -1661,8 +1721,6 @@ on_channels_change_event (BaconVideoWidget *bvw, Totem *totem)
 	/* updated stream info (new song) */
 	name = totem_get_nice_name_for_stream (totem);
 
-	totem_metadata_updated (totem, NULL, NULL, NULL);
-
 	if (name != NULL) {
 		update_mrl_label (totem, name);
 		totem_playlist_set_title
@@ -1689,8 +1747,6 @@ on_got_metadata_event (BaconVideoWidget *bvw, Totem *totem)
 {
         char *name = NULL;
 	
-	totem_metadata_updated (totem, NULL, NULL, NULL);
-
 	name = totem_get_nice_name_for_stream (totem);
 
 	if (name != NULL) {
@@ -1699,9 +1755,6 @@ on_got_metadata_event (BaconVideoWidget *bvw, Totem *totem)
 		g_free (name);
 	}
 	
-	totem_action_set_sensitivity ("take-screenshot",
-				      bacon_video_widget_can_get_frames (bvw, NULL));
-	
 	on_playlist_change_name (TOTEM_PLAYLIST (totem->playlist), totem);
 }
 
@@ -1810,6 +1863,7 @@ update_current_time (BaconVideoWidget *bvw,
 void
 volume_button_value_changed_cb (GtkScaleButton *button, gdouble value, Totem *totem)
 {
+	totem->muted = FALSE;
 	bacon_video_widget_set_volume (totem->bvw, value);
 }
 
@@ -2337,7 +2391,7 @@ totem_action_remote (Totem *totem, TotemRemoteCommand cmd, const char *url)
 		/* TODO - how to see if can, and play the DVD (like the menu item) */
 		break;
 	case TOTEM_REMOTE_COMMAND_MUTE:
-		totem_action_volume_relative (totem, -1.0);
+		totem_action_volume_toggle_mute (totem);
 		break;
 	case TOTEM_REMOTE_COMMAND_TOGGLE_ASPECT:
 		totem_action_toggle_aspect_ratio (totem);
@@ -2350,7 +2404,7 @@ totem_action_remote (Totem *totem, TotemRemoteCommand cmd, const char *url)
 	if (handled != FALSE
 			&& gtk_window_is_active (GTK_WINDOW (totem->win))
 			&& totem_fullscreen_is_fullscreen (totem->fs) != FALSE) {
-		totem_fullscreen_motion_notify (NULL, NULL, totem->fs);
+		totem_fullscreen_show_popups (totem->fs, TRUE);
 	}
 }
 
@@ -2556,7 +2610,7 @@ static void
 on_mouse_click_fullscreen (GtkWidget *widget, Totem *totem)
 {
 	if (totem_fullscreen_is_fullscreen (totem->fs) != FALSE)
-		totem_fullscreen_motion_notify (NULL, NULL, totem->fs);
+		totem_fullscreen_show_popups (totem->fs, TRUE);
 }
 
 static gboolean
@@ -2751,19 +2805,6 @@ totem_action_handle_key_press (Totem *totem, GdkEventKey *event)
 #endif /* HAVE_XFREE */
 		totem_action_zoom_relative (totem, ZOOM_IN_OFFSET);
 		break;
-#ifdef HAVE_XFREE
-	case XF86XK_Save:
-		totem_action_take_screenshot (totem);
-		break;
-#endif /* HAVE_XFREE */
-	case GDK_s:
-	case GDK_S:
-		if (event->state & GDK_CONTROL_MASK) {
-			totem_action_take_screenshot (totem);
-		} else {
-			return FALSE;
-		}
-		break;
 	case GDK_t:
 	case GDK_T:
 #ifdef HAVE_XFREE
@@ -2783,16 +2824,19 @@ totem_action_handle_key_press (Totem *totem, GdkEventKey *event)
 			totem_action_fullscreen (totem, FALSE);
 		break;
 	case GDK_Left:
-		if (gtk_widget_get_direction (totem->win) == GTK_TEXT_DIR_RTL)
-			totem_action_handle_seek (totem, event, TRUE);
-		else
-			totem_action_handle_seek (totem, event, FALSE);
-		break;
 	case GDK_Right:
-		if (gtk_widget_get_direction (totem->win) == GTK_TEXT_DIR_RTL)
-			totem_action_handle_seek (totem, event, FALSE);
-		else
-			totem_action_handle_seek (totem, event, TRUE);
+		{
+			gboolean is_forward;
+
+			if (totem_is_fullscreen (totem) != FALSE)
+				totem_fullscreen_show_popups (totem->fs, FALSE);
+
+			is_forward = (event->keyval == GDK_Right);
+			/* Switch direction in RTL environment */
+			if (gtk_widget_get_direction (totem->win) == GTK_TEXT_DIR_RTL)
+				is_forward = !is_forward;
+			totem_action_handle_seek (totem, event, is_forward);
+		}
 		break;
 	case GDK_space:
 		if (totem_is_fullscreen (totem) != FALSE || gtk_widget_is_focus (GTK_WIDGET (totem->bvw)) != FALSE)
@@ -2883,7 +2927,7 @@ totem_action_handle_scroll (Totem *totem, GdkScrollDirection direction)
 	gboolean retval = TRUE;
 
 	if (totem_fullscreen_is_fullscreen (totem->fs) != FALSE)
-		totem_fullscreen_motion_notify (NULL, NULL, totem->fs);
+		totem_fullscreen_show_popups (totem->fs, TRUE);
 
 	switch (direction) {
 	case GDK_SCROLL_UP:
@@ -2902,13 +2946,8 @@ totem_action_handle_scroll (Totem *totem, GdkScrollDirection direction)
 int
 window_key_press_event_cb (GtkWidget *win, GdkEventKey *event, Totem *totem)
 {
-	GtkWidget *focused;
-
-	focused = gtk_window_get_focus (GTK_WINDOW (totem->win));
-	if (focused != NULL && gtk_widget_is_ancestor
-			(focused, GTK_WIDGET (totem->sidebar)) != FALSE) {
+	if (totem_sidebar_is_focused (totem) != FALSE)
 		return FALSE;
-	}
 
 	/* Special case Eject, Open, Open URI and
 	 * seeking keyboard shortcuts */
@@ -2970,7 +3009,7 @@ window_key_press_event_cb (GtkWidget *win, GdkEventKey *event, Totem *totem)
 	}
 }
 
-int
+gboolean
 window_scroll_event_cb (GtkWidget *win, GdkEventScroll *event, Totem *totem)
 {
 	return totem_action_handle_scroll (totem, event->direction);
@@ -3134,8 +3173,6 @@ totem_callback_connect (Totem *totem)
 	GtkBox *box;
 
 	/* Menu items */
-	gtk_action_group_set_visible (totem->zoom_action_group,
-		bacon_video_widget_can_set_zoom (totem->bvw));
 	action = GTK_ACTION (gtk_builder_get_object (totem->xml, "deinterlace"));
 	gtk_action_set_visible (action, bacon_video_widget_can_deinterlace (totem->bvw));
 
@@ -3181,11 +3218,14 @@ totem_callback_connect (Totem *totem)
 	item = gtk_toggle_button_new ();
 	gtk_action_connect_proxy (action, item);
 	arrow = gtk_arrow_new (GTK_ARROW_RIGHT, GTK_SHADOW_NONE);
-	gtk_widget_show (arrow);
+	g_object_set_data (G_OBJECT (box), "arrow", arrow);
+	gtk_button_set_image_position (GTK_BUTTON (item), GTK_POS_RIGHT);
 	gtk_button_set_image (GTK_BUTTON (item), arrow);
 	gtk_box_pack_start (box, item, FALSE, FALSE, 0);
 	g_signal_connect (G_OBJECT (item), "drag_data_received",
 			G_CALLBACK (drop_playlist_cb), totem);
+	g_signal_connect (G_OBJECT (item), "drag_motion",
+			G_CALLBACK (drag_motion_playlist_cb), totem);
 	gtk_drag_dest_set (item, GTK_DEST_DEFAULT_ALL,
 			target_table, G_N_ELEMENTS (target_table),
 			GDK_ACTION_COPY | GDK_ACTION_MOVE);
@@ -3220,11 +3260,14 @@ totem_callback_connect (Totem *totem)
 	gtk_widget_add_events (totem->seek, GDK_SCROLL_MASK);
 	gtk_widget_add_events (totem->fs->seek, GDK_SCROLL_MASK);
 
-	/* FIXME Hack to fix bug #462286 */
+	/* FIXME Hack to fix bug #462286 and #563894 */
 	g_signal_connect (G_OBJECT (totem->fs->seek), "button-press-event",
 			G_CALLBACK (seek_slider_pressed_cb), totem);
 	g_signal_connect (G_OBJECT (totem->fs->seek), "button-release-event",
 			G_CALLBACK (seek_slider_released_cb), totem);
+	g_signal_connect (G_OBJECT (totem->fs->seek), "scroll-event",
+			  G_CALLBACK (window_scroll_event_cb), totem);
+
 
 	/* Set sensitivity of the toolbar buttons */
 	totem_action_set_sensitivity ("play", FALSE);
@@ -3297,7 +3340,6 @@ video_widget_create (Totem *totem)
 			g_error_free (err);
 	}
 
-	totem_preferences_tvout_setup (totem);
 	totem_action_zoom (totem, ZOOM_RESET);
 
 	g_signal_connect_after (G_OBJECT (totem->bvw),
@@ -3351,6 +3393,8 @@ video_widget_create (Totem *totem)
 
 	g_signal_connect (G_OBJECT (totem->bvw), "drag_data_received",
 			G_CALLBACK (drop_video_cb), totem);
+	g_signal_connect (G_OBJECT (totem->bvw), "drag_motion",
+			G_CALLBACK (drag_motion_video_cb), totem);
 	gtk_drag_dest_set (GTK_WIDGET (totem->bvw), GTK_DEST_DEFAULT_ALL,
 			target_table, G_N_ELEMENTS (target_table),
 			GDK_ACTION_COPY | GDK_ACTION_MOVE);
@@ -3406,16 +3450,47 @@ totem_message_connection_receive_cb (const char *msg, Totem *totem)
 	g_free (url);
 }
 
+static void
+about_url_hook (GtkAboutDialog *about,
+	        const char *link,
+	        gpointer user_data)
+{
+	GError *error = NULL;
+
+	if (!gtk_show_uri (gtk_widget_get_screen (GTK_WIDGET (about)),
+	                   link,
+	                   gtk_get_current_event_time (),
+	                   &error))
+	{
+	        totem_interface_error (_("Could not open link"),
+	                               error->message,
+	                               GTK_WINDOW (about));
+	        g_error_free (error);
+	}
+}
+
+
+static void
+about_email_hook (GtkAboutDialog *about,
+		  const char *email_address,
+		  gpointer user_data)
+{
+	char *escaped, *uri;
+
+	escaped = g_uri_escape_string (email_address, NULL, FALSE);
+	uri = g_strdup_printf ("mailto:%s", escaped);
+	g_free (escaped);
+
+	about_url_hook (about, uri, user_data);
+	g_free (uri);
+}
+
 int
 main (int argc, char **argv)
 {
 	Totem *totem;
 	GConfClient *gc;
-#ifndef HAVE_GTK_ONLY
-	GnomeProgram *program;
-#else
 	GError *error = NULL;
-#endif
 	GOptionContext *context;
 	GOptionGroup *baconoptiongroup;
 	char *sidebar_pageid;
@@ -3443,25 +3518,20 @@ main (int argc, char **argv)
 	g_option_context_set_translation_domain(context, GETTEXT_PACKAGE);
 	g_option_context_add_group (context, baconoptiongroup);
 
-#ifdef HAVE_GTK_ONLY
 	g_option_context_add_group (context, gtk_get_option_group (TRUE));
 	if (g_option_context_parse (context, &argc, &argv, &error) == FALSE) {
 		g_print (_("%s\nRun '%s --help' to see a full list of available command line options.\n"),
 				error->message, argv[0]);
 		g_error_free (error);
+	        g_option_context_free (context);
 		totem_action_exit (NULL);
 	}
-#else
-	program = gnome_program_init (PACKAGE, VERSION,
-			LIBGNOMEUI_MODULE,
-			argc, argv,
-			GNOME_PARAM_APP_DATADIR, DATADIR,
-			GNOME_PARAM_GOPTION_CONTEXT, context,
-			GNOME_PARAM_NONE);
-#endif /* HAVE_GTK_ONLY */
+	g_option_context_free (context);
 
 	g_set_application_name (_("Totem Movie Player"));
 	gtk_window_set_default_icon_name ("totem");
+	gtk_about_dialog_set_url_hook (about_url_hook, NULL, NULL);
+	gtk_about_dialog_set_email_hook (about_email_hook, NULL, NULL);
 
 	gc = gconf_client_get_default ();
 	if (gc == NULL)
@@ -3578,9 +3648,5 @@ main (int argc, char **argv)
 
 	gtk_main ();
 
-#ifndef HAVE_GTK_ONLY
-	/* Will destroy GOption allocated data automatically */
-	g_object_unref (program);
-#endif	
 	return 0;
 }
