@@ -105,7 +105,8 @@ typedef struct {
 	void (*metadata_updated)		(Totem *totem,
 						 const char *artist,
 						 const char *title,
-						 const char *album);
+						 const char *album,
+						 guint track_num);
 } TotemObjectClass;
 
 GType	totem_object_get_type			(void);
@@ -117,7 +118,8 @@ void	totem_file_closed			(TotemObject *totem);
 void	totem_metadata_updated			(TotemObject *totem,
 						 const char *artist,
 						 const char *title,
-						 const char *album);
+						 const char *album,
+						 guint track_num);
 
 void	totem_action_exit			(Totem *totem) G_GNUC_NORETURN;
 void	totem_action_play			(Totem *totem);
@@ -131,6 +133,7 @@ void	totem_action_previous			(Totem *totem);
 void	totem_action_seek_time			(Totem *totem, gint64 sec);
 void	totem_action_seek_relative		(Totem *totem, gint64 offset);
 void	totem_action_volume_relative		(Totem *totem, double off_pct);
+void	totem_action_volume_toggle_mute		(Totem *totem);
 gboolean totem_action_set_mrl			(Totem *totem,
 						 const char *mrl,
 						 const char *subtitle);
@@ -177,7 +180,7 @@ gint64	totem_get_current_time			(Totem *totem);
 guint	totem_get_playlist_length		(Totem *totem);
 void	totem_action_set_playlist_index		(Totem *totem,
 						 guint index);
-guint	totem_get_playlist_pos			(Totem *totem);
+int	totem_get_playlist_pos			(Totem *totem);
 char *	totem_get_title_at_playlist_pos		(Totem *totem,
 						 guint index);
 void totem_add_to_playlist_and_play		(Totem *totem,
@@ -185,7 +188,8 @@ void totem_add_to_playlist_and_play		(Totem *totem,
 						 const char *display_name,
 						 gboolean add_to_recent);
 char *  totem_get_current_mrl			(Totem *totem);
-
+void	totem_set_current_subtitle		(Totem *totem,
+						 const char *subtitle_uri);
 /* Sidebar handling */
 void    totem_add_sidebar_page			(Totem *totem,
 						 const char *page_id,
